==> redquicklib-1.289.0.tgz: package/lib/components/creditcardreader.js <==
import React, { Component } from 'react';
import { connect } from 'react-redux';
// import {
//     CardIOView,
//     CardIOUtilities,
//     CardIOModule
// } from 'react-native-awesome-card-io';
import {
    Container,
    Header,
    Content,
    Footer,
    FooterTab,
    Button,
    Icon,
    List,
    ListItem,
    InputGroup,
    Input,
    Body,
    Title,
    Left,
    Right,
    Card,
    Spinner,
    CardItem,

} from 'native-base';
import * as Common from '../common';

import {
    Text,
    StyleSheet,
    View,
    Platform,
    Item, Image,
    TouchableOpacity,
    Picker, Dimensions
} from 'react-native';

import * as utils from '../util';


import * as Titles from '../titles';



import { Actions } from 'react-native-router-flux';
const listpadding = 20;
const { width, height } = Dimensions.get('window');

class CreditCardReader extends Component {
    constructor(props) {
        super(props);
        this.state = {
        };
    }
    componentWillMount() {
        if (Platform.OS === 'ios') {
            CardIOUtilities.preload();
        }
    }

    didScanCard = (card) => {
        // the scanned card
        var me = this;
        console.log(card);
    }

    scanCard() {
        var me = this;
        Common
            .scanCard(card => {
                console.log(card);
                // the scanned card
                if (me.props.callback) {
                    me.props.callback({ card });
                }
            })
    }
    render() {
        var me = this;
        return (
            <Container>
                <Header >
                    <Button transparent onPress={() => { Actions.pop() }}>
                        <Icon name='md-arrow-round-back' />
                    </Button>
                    <Body>
                        <Title>{Titles.ScanCard}</Title>
                    </Body>
                </Header>
                <Content>
                    <View>
                        <CardIOView
                            didScanCard={me.didScanCard.bind(me)}
                            style={{ flex: 1 }}
                        />
                    </View>
                </Content>
                <Footer>
                    <FooterTab>
                        <Button onPress={this.scanCard.bind(this)}>
                            <Text>{Titles.ScanCard}</Text>
                        </Button>
                    </FooterTab>
                </Footer>
            </Container>
        );
    }
}
export default connect(utils.mapStateToProps, utils.mapDispatchToProps)(CreditCardReader);

==> redquicklib-1.500.0.tgz: package/lib/components/creditcardreader.js <==
import React, { Component } from 'react';
import { connect } from 'react-redux';
// import {
//     CardIOView,
//     CardIOUtilities,
//     CardIOModule
// } from 'react-native-awesome-card-io';
import {
    Container,
    Header,
    Content,
    Footer,
    FooterTab,
    Button,
    Icon,
    List,
    ListItem,
    InputGroup,
    Input,
    Body,
    Title,
    Left,
    Right,
    Card,
    Spinner,
    CardItem,

} from 'native-base';
import * as Common from '../common';

import {
    Text,
    StyleSheet,
    View,
    Platform,
    Item, Image,
    TouchableOpacity,
    Picker, Dimensions
} from 'react-native';

import * as utils from '../redutil';


import * as Titles from '../titles';



import { Actions } from 'react-native-router-flux';
const listpadding = 20;
const { width, height } = Dimensions.get('window');

class CreditCardReader extends Component {
    constructor(props) {
        super(props);
        this.state = {
        };
    }
    componentWillMount() {
        if (Platform.OS === 'ios') {
            CardIOUtilities.preload();
        }
    }

    didScanCard = (card) => {
        // the scanned card
        var me = this;
        console.log(card);
    }

    scanCard() {
        var me = this;
        Common
            .scanCard(card => {
                console.log(card);
                // the scanned card
                if (me.props.callback) {
                    me.props.callback({ card });
                }
            })
    }
    render() {
        var me = this;
        return (
            <Container>
                <Header >
                    <Button transparent onPress={() => { Actions.pop() }}>
                        <Icon name='md-arrow-round-back' />
                    </Button>
                    <Body>
                        <Title>{Titles.ScanCard}</Title>
                    </Body>
                </Header>
                <Content>
                    <View>
                        <CardIOView
                            didScanCard={me.didScanCard.bind(me)}
                            style={{ flex: 1 }}
                        />
                    </View>
                </Content>
                <Footer>
                    <FooterTab>
                        <Button onPress={this.scanCard.bind(this)}>
                            <Text>{Titles.ScanCard}</Text>
                        </Button>
                    </FooterTab>
                </Footer>
            </Container>
        );
    }
}
export default connect(utils.mapStateToProps, utils.mapDispatchToProps)(CreditCardReader);
